pub struct DepGraphMut<'a> { /* private fields */ }Expand description
A mutable graph view.
This data structure provides a mutable view of a CoNLL-X dependency
graph. The view can be used to retrieve the dependents of a head or
the head of a dependent. In addition, the add_deprel method can be
used to add dependency relations to the graph.
Implementations
Sourceimpl<'a> DepGraphMut<'a>
impl<'a> DepGraphMut<'a>
Sourcepub fn add_deprel<S>(&mut self, triple: DepTriple<S>)
pub fn add_deprel<S>(&mut self, triple: DepTriple<S>)
Add a dependency relation between head and dependent.
If dependent already has a head relation, this relation is removed
to ensure single-headedness.
Sourcepub fn dependents(&self, head: usize) -> impl Iterator<Item = DepTriple<&str>>
pub fn dependents(&self, head: usize) -> impl Iterator<Item = DepTriple<&str>>
Return an iterator over the dependents of head.
Sourcepub fn head(&self, dependent: usize) -> Option<DepTriple<&str>>
pub fn head(&self, dependent: usize) -> Option<DepTriple<&str>>
Return the head relation of dependent, if any.